==> mmoo_base-1.2.2%2B1.tar.gz: lib/utils/permissions_utils.dart <==
import 'dart:io';

import 'package:mmoo_base/config/app_config.dart';
import 'package:permission_handler/permission_handler.dart';

///定义一个抽象类-媒体工具
abstract class OnPermissionsPluginDelegate {
  void showDialogPermissions(bool chat, int index, callback);

  ///埋点统计
  void logEvent(String name);
}

///媒体工具，负责申请权限，选照片，拍照，录音，播放语音
class PermissionsUtils {
  factory PermissionsUtils() => _getInstance();

  static PermissionsUtils get instance => _getInstance();
  static PermissionsUtils? _instance;

  PermissionsUtils._internal();

  static PermissionsUtils _getInstance() {
    _instance ??= PermissionsUtils._internal();
    return _instance!;
  }

  OnPermissionsPluginDelegate? delegate;

  void initPermissionsUtil(OnPermissionsPluginDelegate delegate) {
    this.delegate = delegate;
  }

  //请求权限: 相册，相机，麦克风 index 0相机 1相册 2麦克风 3文件
  Future<bool?> grantedPermissions({bool chat = false, int index = -1}) async {
    bool have = true;
    PermissionStatus status;
    if (chat) {
      status = await Permission.camera.status;
      if (status != PermissionStatus.granted) {
        have = false;
      }
      if (checkDenied(status)) {
        return null;
      }
      status = await Permission.microphone.status;
      if (status != PermissionStatus.granted) {
        have = false;
      }
      if (checkDenied(status)) {
        return null;
      }
    } else if (index == 0) {
      status = await Permission.camera.status;
      if (status != PermissionStatus.granted) {
        have = false;
      }
      if (checkDenied(status)) {
        return null;
      }
    } else if (index == 1) {
      status = Platform.isAndroid
          ? await Permission.storage.status
          : await Permission.photos.status;
      if (status != PermissionStatus.granted &&
          status != PermissionStatus.limited) {
        have = false;
      }
      if (checkDenied(status)) {
        return null;
      }
    } else if (index == 2) {
      status = await Permission.microphone.status;
      if (status != PermissionStatus.granted) {
        have = false;
      }
      if (checkDenied(status)) {
        return null;
      }
    } else {
      status = await Permission.storage.status;
      if (status != PermissionStatus.granted &&
          status != PermissionStatus.limited) {
        have = false;
      }
      if (checkDenied(status)) {
        return null;
      }
    }
    return have;
  }

  bool checkDenied(PermissionStatus status) {
    return Platform.isAndroid && status == PermissionStatus.permanentlyDenied ||
        Platform.isIOS && status == PermissionStatus.restricted;
  }

  void showDenied(bool chat, int index) {
    delegate?.showDialogPermissions(chat, index, (position) {
      if (position == 1) {
        openAppSettings();
      }
    });
  }

  //请求权限:相册，相机，麦克风
  void requestPermissions(back, {bool chat = true, int index = -1}) async {
    Map<Permission, PermissionStatus> rest;
    if (chat) {
      rest = await [
        Permission.camera,
        Permission.microphone,
      ].request();
    } else if (index == 0) {
      rest = await [
        Permission.camera,
      ].request();
    } else if (index == 1) {
      rest = await [
        Platform.isAndroid ? Permission.storage : Permission.photos,
      ].request();
    } else if (index == 2) {
      rest = await [
        Permission.microphone,
      ].request();
    } else {
      rest = await [
        Permission.storage,
      ].request();
    }
    AppConfig.printLog(rest);
    bool denied = rest.containsValue(PermissionStatus.permanentlyDenied) ||
        rest.containsValue(PermissionStatus.restricted);
    if (denied) {
      showDenied(chat, index);
    } else if (chat) {
      if (rest[Permission.camera] == PermissionStatus.granted) {
        delegate?.logEvent('用户同意摄像头权限');
      } else {
        delegate?.logEvent('用户拒绝摄像头权限');
      }
      if (rest[Permission.microphone] == PermissionStatus.granted) {
        delegate?.logEvent('用户同意麦克风权限');
      } else {
        delegate?.logEvent('用户拒绝麦克风权限');
      }
    } else if (index == 0) {
      if (rest[Permission.camera] == PermissionStatus.granted) {
        delegate?.logEvent('用户同意摄像头权限');
      } else {
        delegate?.logEvent('用户拒绝摄像头权限');
      }
    } else if (index == 2) {
      if (rest[Permission.microphone] == PermissionStatus.granted) {
        delegate?.logEvent('用户同意麦克风权限');
      } else {
        delegate?.logEvent('用户拒绝麦克风权限');
      }
    }
    bool allOk = true;
    for (var element in rest.values) {
      if (index == 1 &&
          element != PermissionStatus.granted &&
          element != PermissionStatus.limited) {
        allOk = false;
      } else if (index != 1 && element != PermissionStatus.granted) {
        allOk = false;
      }
    }
    back?.call(allOk);
  }

  void requestPermissionsNotification() async {
    PermissionStatus status = await Permission.notification.status;
    if (status == PermissionStatus.denied) {
      PermissionStatus rest = await Permission.notification.request();
      AppConfig.printLog(rest);
      if (rest == PermissionStatus.granted) {
        delegate?.logEvent('用户同意通知权限');
      } else {
        delegate?.logEvent('用户拒绝通知权限');
      }
    } else if (status == PermissionStatus.granted) {
      delegate?.logEvent('用户同意通知权限');
    }
  }
}

==> mmoo_base-1.3.0%2B1.tar.gz: lib/utils/permissions_utils.dart <==
import 'dart:io';

import 'package:mmoo_base/config/app_config.dart';
import 'package:permission_handler/permission_handler.dart';

///定义一个抽象类-媒体工具
abstract class OnPermissionsPluginDelegate {
  void showDialogPermissions(bool chat, int index, callback);

  ///埋点统计
  void logEvent(String name);
}

///媒体工具，负责申请权限，选照片，拍照，录音，播放语音
class PermissionsUtils {
  factory PermissionsUtils() => _getInstance();

  static PermissionsUtils get instance => _getInstance();
  static PermissionsUtils? _instance;

  PermissionsUtils._internal();

  static PermissionsUtils _getInstance() {
    _instance ??= PermissionsUtils._internal();
    return _instance!;
  }

  OnPermissionsPluginDelegate? delegate;

  void initPermissionsUtil(OnPermissionsPluginDelegate delegate) {
    this.delegate = delegate;
  }

  //请求权限: 相册，相机，麦克风 index 0相机 1相册 2麦克风 3文件
  Future<bool?> grantedPermissions({bool chat = false, int index = -1}) async {
    bool have = true;
    PermissionStatus status;
    if (chat) {
      status = await Permission.camera.status;
      if (status != PermissionStatus.granted) {
        have = false;
      }
      if (checkDenied(status)) {
        return null;
      }
      status = await Permission.microphone.status;
      if (status != PermissionStatus.granted) {
        have = false;
      }
      if (checkDenied(status)) {
        return null;
      }
    } else if (index == 0) {
      status = await Permission.camera.status;
      if (status != PermissionStatus.granted) {
        have = false;
      }
      if (checkDenied(status)) {
        return null;
      }
    } else if (index == 1) {
      status = Platform.isAndroid
          ? await Permission.storage.status
          : await Permission.photos.status;
      if (status != PermissionStatus.granted &&
          status != PermissionStatus.limited) {
        have = false;
      }
      if (checkDenied(status)) {
        return null;
      }
    } else if (index == 2) {
      status = await Permission.microphone.status;
      if (status != PermissionStatus.granted) {
        have = false;
      }
      if (checkDenied(status)) {
        return null;
      }
    } else if (index == 4) {
      status = await Permission.phone.status;
      if (status != PermissionStatus.granted) {
        have = false;
      }
      if (checkDenied(status)) {
        return null;
      }
    } else {
      status = await Permission.storage.status;
      if (status != PermissionStatus.granted &&
          status != PermissionStatus.limited) {
        have = false;
      }
      if (checkDenied(status)) {
        return null;
      }
    }
    return have;
  }

  bool checkDenied(PermissionStatus status) {
    return Platform.isAndroid && status == PermissionStatus.permanentlyDenied ||
        Platform.isIOS && status == PermissionStatus.restricted;
  }

  void showDenied(bool chat, int index) {
    delegate?.showDialogPermissions(chat, index, (position) {
      if (position == 1) {
        openAppSettings();
      }
    });
  }

  //请求权限:相册，相机，麦克风
  Future<bool> requestPermissions({bool chat = true, int index = -1}) async {
    Map<Permission, PermissionStatus> rest;
    if (chat) {
      rest = await [
        Permission.camera,
        Permission.microphone,
      ].request();
    } else if (index == 0) {
      rest = await [
        Permission.camera,
      ].request();
    } else if (index == 1) {
      rest = await [
        Platform.isAndroid ? Permission.storage : Permission.photos,
      ].request();
    } else if (index == 2) {
      rest = await [
        Permission.microphone,
      ].request();
    } else if (index == 4) {
      rest = await [
        Permission.phone,
      ].request();
    } else {
      rest = await [
        Permission.storage,
      ].request();
    }
    AppConfig.printLog(rest);
    bool denied = rest.containsValue(PermissionStatus.permanentlyDenied) ||
        rest.containsValue(PermissionStatus.restricted);
    if (denied) {
      showDenied(chat, index);
    } else if (chat) {
      if (rest[Permission.camera] == PermissionStatus.granted) {
        delegate?.logEvent('用户同意摄像头权限');
      } else {
        delegate?.logEvent('用户拒绝摄像头权限');
      }
      if (rest[Permission.microphone] == PermissionStatus.granted) {
        delegate?.logEvent('用户同意麦克风权限');
      } else {
        delegate?.logEvent('用户拒绝麦克风权限');
      }
    } else if (index == 0) {
      if (rest[Permission.camera] == PermissionStatus.granted) {
        delegate?.logEvent('用户同意摄像头权限');
      } else {
        delegate?.logEvent('用户拒绝摄像头权限');
      }
    } else if (index == 2) {
      if (rest[Permission.microphone] == PermissionStatus.granted) {
        delegate?.logEvent('用户同意麦克风权限');
      } else {
        delegate?.logEvent('用户拒绝麦克风权限');
      }
    }
    bool allOk = true;
    for (var element in rest.values) {
      if (index == 1 &&
          element != PermissionStatus.granted &&
          element != PermissionStatus.limited) {
        allOk = false;
      } else if (index != 1 && element != PermissionStatus.granted) {
        allOk = false;
      }
    }
    return allOk;
  }

  void requestPermissionsNotification() async {
    PermissionStatus status = await Permission.notification.status;
    if (status == PermissionStatus.denied) {
      PermissionStatus rest = await Permission.notification.request();
      AppConfig.printLog(rest);
      if (rest == PermissionStatus.granted) {
        delegate?.logEvent('用户同意通知权限');
      } else {
        delegate?.logEvent('用户拒绝通知权限');
      }
    } else if (status == PermissionStatus.granted) {
      delegate?.logEvent('用户同意通知权限');
    }
  }
}
